/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * The Initial Developer of this code is David Baum.
 * Portions created by David Baum are Copyright (C) 1998 David Baum.
 * All Rights Reserved.
 */

package pbsim;

public class Datalog {

	// constants for tags (must match actual RCX)
	public static final int VARIABLE = 0;
	public static final int TIMER = 0x20;
	public static final int SENSOR = 0x40;
	public static final int WATCH = 0x80;
	public static final int TYPE_MASK = 0xe0;
	public static final int INDEX_MASK = 0x1f;
	
	private int	length;
	private int	pos;
	private int values[];
	private int tags[];
	private PBrick pbrick;
	
	
	Datalog(PBrick pb) {
		length = 0;
		pos = 0;
		this.pbrick = pb;
	}
	
	public int getLength() { return length; }
	public int getPos() { return pos; }
	public int getValue(int i) { return values[i]; }
	public int getTag(int i) { return tags[i]; }
	
	
	void resize(int n) {
		length = n;
		values = new int[n];
		tags = new int[n];
		pos = 0;
	}
	
	
	void add(int src, int value) {
		if (pos == length) return;
		
		// determine tag
		int t;
		switch(src)
		{
			case Src.VARIABLE:
				t = VARIABLE;
				break;
			case Src.TIMER:
				t = TIMER;
				break;
			case Src.SENSOR_VALUE:
				t = SENSOR;
				break;
			case Src.WATCH:
				t = WATCH;
				break;
			default:
				return;
		}
				
		tags[pos] = t + (value & INDEX_MASK);
		values[pos] = pbrick.evaluate(src, value);
		++pos;
	}
}
