/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * The Initial Developer of this code is David Baum.
 * Portions created by David Baum are Copyright (C) 1998 David Baum.
 * All Rights Reserved.
 */

package pbsim;

/**	A specialization of the PBrick class that simulates an RCX.
 *
 */
public class RCX extends PBrick
{
	private static int rcxOpcodes[] = {
		Op.SENT, Op.SETW, // RCX only
		Op.SENM, Op.SENZ, // RCX/CM
		Op.MSG, Op.MSGZ, Op.MSGS, Op.TXS,	// RCX/Scout
	};
	

	private static int rcx2Opcodes[] = {
		// RCX2/Scout
		Op.PLAYV, Op.DECVJN, Op.DECVJNL,
		Op.MONEL, Op.MONEX, Op.MONE, Op.EVENT,
		Op.GOUT, Op.GDIR, Op.GPWR,
		Op.MONAL, Op.MONAX, Op.SETP,
		
		// RCX2 only
		Op.MUTE, Op.SPEAK, Op.PLAYZ, Op.DISP, Op.SET,
		Op.SETE, Op.DELE,
	};


	public RCX() {
		super(6300, 5, 10, 8, 32, 16);
		createOutputs(3);
		createTimers(4);
		createSensors(3);
		createDatalog();
		createLoopCounters(4);
		createDisplay();
		enableOpcodes(rcxOpcodes);
		
		// rcx2
		createCounters(3, true);
		enableOpcodes(rcx2Opcodes);
		createEvents(16);
	}
};
