/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * The Initial Developer of this code is David Baum.
 * Portions created by David Baum are Copyright (C) 1998 David Baum.
 * All Rights Reserved.
 */

package pbsim;

/** This interface is used by the simulator to inform the client
*	when the simulated PBrick plays or cancels a sound.
*/


public interface SoundListener {
	// codes for pbControlSound
	/** control code for muting all sound */
	public static final int MUTE = 0;
	
	/** control code for un-muting all sound */
	public static final int UNMUTE = 1;	
	
	/** control code for cancelling all pending sounds */
	public static final int CLEAR = 2;
	
	/** This method is called when a system sound is played.
	*	@param number the number of the system sound
	*/
	public void pbPlaySound(int number);
	
	
	/** This method is called when a tone is played.
	*	@param freq the frequency of the tone (in Hz)
	*	@param duration	the duration of the tone (in 10ms ticks)
	*/
	public void pbPlayTone(int freq, int duration);
	
	/** This method is called when the sound system is altered.
	*	@param code one of the control codes (MUTE, UNMUTE, or CLEAR)
	*/
	public void pbControlSound(int code);
}