/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * The Initial Developer of this code is David Baum.
 * Portions created by David Baum are Copyright (C) 1998 David Baum.
 * All Rights Reserved.
 */

package pbsim;

class Storage {
	private short	globals[];
	private short	locals[][]; 
	private int		globalCount;
	private DebugListener debugListener;
	private Counter counters[];
	private int		counterCount;
	
	Storage(int globalCount, int localCount, int taskCount) {
		this.globalCount = globalCount;
		globals = new short[globalCount];
		locals = new short[taskCount][localCount];
	}
	
	void setDebugListener(DebugListener l) { debugListener = l; }
	
	short get(int i, int task) {
		if (i < counterCount)
			return counters[i].get();
		else if (i < globalCount)
			return globals[i];
		else
			return locals[task][i-globalCount];
	}
	
	short getGlobal(int i) {
		if (i < counterCount)
			return counters[i].get();
		else
			return globals[i];
	}
		
	short getLocal(int i, int task) {
		return locals[task][i];
	}
	
	
	void overlapCounters(Counter counters[]) {
		this.counters = counters;
		counterCount = counters.length;
		
	}
	
	void set(int i, int task, short v) {
		if (i < globalCount)
			setGlobal(i,v);
		else
			setLocal(i-globalCount, task, v);
	}
	
	void setGlobal(int i, short v) {
		if (i < counterCount) {
			counters[i].set(v);
		}
		else {
			if (globals[i] == v) return;
			
			globals[i] = v;
		}
	}
	
	void setLocal(int i, int t, short v) {
		if (locals[t][i] == v) return;
		
		locals[t][i] = v;
	}
}
