/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * The Initial Developer of this code is David Baum.
 * Portions created by David Baum are Copyright (C) 1998 David Baum.
 * All Rights Reserved.
 */

package pbsim;

class Timer {
	private static final int FAST_PER_TICK = 10;
	
	private int id;
	private int ticks;
	private int fast;
	
	private TriggerQueue triggers;
	
	Timer(int id) {
		this.id = id;
		triggers = new TriggerQueue();
	}
	
	void clear() {
		ticks = 0;
		fast = 0;
		triggers.update(ticks, 0);
	}
	
	
	void set(int t) {
		ticks = t & 0x7fff; // leave fast phase unchanged
		triggers.update(ticks, 0);
	}
	
	
	void setFast(int t) {
		ticks = (t / 10) & 0x7fff;
		fast = t % 10;
		triggers.update(ticks, 0);	
	}
	
	
	void tick() {
		if (++fast != FAST_PER_TICK) return;
		
		fast = 0;
		ticks = (ticks + 1) & 0x7fff;		
		triggers.update(ticks, 0);
	}
	
	
	int	getTicks() {
		return ticks;
	}


	int getFast() {
		return (ticks * 10 + fast) & 0x7fff;
	}
	
	
	void addTrigger(Trigger t) {
		t.enqueue(triggers);
		t.prime(ticks, 0, PBrick.MAX_INT);
	}
}